@@ -42,7 +42,14 @@ typedef enum {
         PED_DEVICE_FILE         = 5,
         PED_DEVICE_ATARAID      = 6,
         PED_DEVICE_I2O          = 7,
-        PED_DEVICE_UBD          = 8
+        PED_DEVICE_UBD          = 8,
+        PED_DEVICE_DASD         = 9,
+        PED_DEVICE_VIODASD      = 10,
+        PED_DEVICE_SX8          = 11
+#ifdef ENABLE_DEVICE_MAPPER
+                                    ,
+        PED_DEVICE_DM           = 12
+#endif
 } PedDeviceType;
 
 typedef struct _PedDevice PedDevice;
