@@ -1284,7 +1284,9 @@ gpt_partition_enumerate (PedPartition* part)
 		}
 	}
 
-	PED_ASSERT (0, return 0); return 0;
+	PED_ASSERT (0, return 0);
+
+	return 0; /* used if debug is disabled */
 }
 
 static int
