@@ -69,8 +69,8 @@ static char* banner_msg = N_(
 
 static char* usage_msg = N_(
 "Usage: parted [OPTION]... [DEVICE [COMMAND [PARAMETERS]...]...]\n"
-"Apply COMMANDs with PARAMETERS to DEVICE.  If no COMMAND(s) are given, run in\n"
-"interactive mode.\n");
+"Apply COMMANDs with PARAMETERS to DEVICE.  If no COMMAND(s) are given, "
+"run in\ninteractive mode.\n");
 
 static char* bug_msg = N_(
 "\n\nYou found a bug in GNU Parted! Here's what you have to do:\n\n"
@@ -185,6 +185,18 @@ _add_history_unique (const char* line)
 }
 #endif /* HAVE_LIBREADLINE */
 
+#ifndef HAVE_SIGACTION
+static void
+mask_signal()
+{
+    sigset_t curr;
+    sigset_t prev;
+  
+    sigfillset(&curr);
+    sigprocmask(SIG_SETMASK, &curr, &prev);
+}
+#endif /* HAVE_SIGACTION */
+
 /* Resets the environment by jumping to the initial state
  * saved during ui intitialisation.
  * Pass 1 as the parameter if you want to quit parted, 
@@ -206,22 +218,33 @@ reset_env (int quit)
 	}
 }
 
-#ifdef HAVE_SIGACTION
-
 /* Signal handler for SIGINT */
 static void
 sigint_handler (int signum, siginfo_t* info, void *ucontext)
 {
     got_ctrl_c = 1;
+
+    #ifdef HAVE_SIGACTION
     sigaction (SIGINT, &sig_int, NULL);
+    #else
+    signal (SIGINT, &sigint_handler);
+    mask_signal();
+    #endif /* HAVE_SIGACTION */
+
     reset_env (0);
 }
 
 /* Signal handler for SIGSEGV */
 static void
 sigsegv_handler (int signum, siginfo_t* info, void* ucontext)
-{   
-    sigaction (SIGINT, &sig_segv, NULL);
+{
+    #ifdef HAVE_SIGACTION   
+    sigaction (SIGSEGV, &sig_segv, NULL);
+    #else
+    signal (SIGSEGV, &sigsegv_handler);
+    mask_signal();
+    #endif /* HAVE_SIGACTION */
+
     printf (bug_msg, VERSION);
     
     switch (info->si_code) {
@@ -249,7 +272,13 @@ sigsegv_handler (int signum, siginfo_t* info, void* ucontext)
 static void
 sigfpe_handler (int signum, siginfo_t* info, void* ucontext)
 {
+    #ifdef HAVE_SIGACTION
     sigaction (SIGFPE, &sig_fpe, NULL);
+    #else
+    signal (SIGFPE, &sigfpe_handler);
+    mask_signal();
+    #endif /* HAVE_SIGACTION */
+
     printf (bug_msg, VERSION);
 
     switch (info->si_code) {
@@ -301,7 +330,13 @@ sigfpe_handler (int signum, siginfo_t* info, void* ucontext)
 static void
 sigill_handler (int signum, siginfo_t* info, void* ucontext)
 {
+    #ifdef HAVE_SIGACTION
     sigaction (SIGILL, &sig_ill, NULL);
+    #else
+    signal (SIGILL, &sigill_handler);
+    mask_signal();
+    #endif /* HAVE_SIGACTION */
+
     printf (bug_msg, VERSION);
 
     switch (info->si_code) {
@@ -348,7 +383,6 @@ sigill_handler (int signum, siginfo_t* info, void* ucontext)
     abort();
 }
 
-#endif /* HAVE_SIGACTION */
 
 static char*
 _readline (const char* prompt, const StrList* possibilities)
@@ -1027,13 +1061,13 @@ command_line_get_ex_opt (const char* prompt, PedExceptionOption options)
 
 	opt = PED_EXCEPTION_OPTION_FIRST;
 	while (1) {
-		opt = option_get_next (options, opt);
 		if (strcmp (opt_name,
 			    ped_exception_get_option_string (opt)) == 0)
 			break;
 		if (strcmp (opt_name,
 			    _(ped_exception_get_option_string (opt))) == 0)
 			break;
+		opt = option_get_next (options, opt);
 	}
 	free (opt_name);
 	return opt;
